@@ -642,6 +642,41 @@ class BaseEnvironnement(BaseEstimator):
         fit, il est conseillé d'utiliser le type DataSet PyTorch comme type 
         d'entré à X.
 
+        **Attention pour les TPU** :
+
+        Les passage de référence dans la construction du graph du type :
+
+        >>> DummiesModel(Module, BaseEnvironnement)
+        >>>     def __ini__(self):
+        >>>         super().__init__()
+        >>>         [...]
+        >>>
+        >>>     def build(self):
+        >>>         self.dense1 = Linear(10, 5)
+        >>>         self.dense2 = Linear(10, 5)
+        >>>         # liaison des poids
+        >>>         self.dense1.weight = self.dense2.weigth
+        [...]
+        
+        ne fonctionne pas sur les devices TPU car les poids sont copiés
+        systématiquement. Il faudra relier de nouveau les poids une fois
+        sur le TPU.
+
+        >>> DummiesModel(Module, BaseEnvironnement)
+        >>>     def __ini__(self):
+        >>>         super().__init__()
+        >>>         [...]
+        >>>
+        >>>     def build(self):
+        >>>         self.dense1 = Linear(10, 5)
+        >>>         self.dense2 = Linear(10, 5)
+        >>>         # liaison des poids
+        >>>         self.dense1.weight = self.dense2.weigth
+        >>>
+        >>>     def post_move_to_tup(self):
+        >>>         self.dense1.weight = self.dense2.weigth
+        [...]
+
         .. _documention PyTorch: https://pytorch.org/docs/stable/data.html
         """
         if not hasattr(self, 'optimizer') and optimizer is None:
@@ -742,6 +777,8 @@ class BaseEnvironnement(BaseEstimator):
                 max_gradient_norm=max_gradient_norm
             )
         self.to(control.device)
+        if control.device.type != "tpu" and hasattr(self, 'post_move_to_tup'):
+            self.post_move_to_tup()
         state_in_loss = list(
             filter(
                 lambda x: 
