@@ -762,7 +762,7 @@ class Backup(CallbackInterface, metaclass=SuperclassDocstring):
                         os.listdir(f"{self.path_backup}/")
                     )
                 ),
-                key=lambda x: os.path.getmtime(x),
+                key=lambda x: os.path.getmtime(f"{self.path_backup}/{x}"),
                 reverse=True
             )[self.nb_backup:]
             for file in files:
@@ -851,8 +851,9 @@ class EarlyStoppingCallback(CallbackInterface, metaclass=SuperclassDocstring):
         self.iter_stop: int = 0
         self.best_epoch: int = 0
         self.best_iter: int = 0
+        self.state_dict = None
         if self.path_early_stopping:
-            if os.path.exists(self.path_early_stopping):
+            if not os.path.exists(self.path_early_stopping):
                 os.makedirs(self.path_early_stopping)
 
     def end_eval(
@@ -916,38 +917,16 @@ class EarlyStoppingCallback(CallbackInterface, metaclass=SuperclassDocstring):
                 f"{self.old_res_loss}.\n",
                 flush=True
             )
-        if self.path_early_stopping is None:
+        if self.path_early_stopping is None and self.state_dict:
             model.load_state_dict(self.state_dict)
-        else:
+        elif os.path.exists(
+            f"{self.path_early_stopping}/{state.id_process}.model"
+        ):
             model.load_weights(
                 f"{self.path_early_stopping}/{state.id_process}.model"
             )
             os.remove(f"{self.path_early_stopping}/{state.id_process}.model")
 
-    def error_interrupt(
-        self,
-        model: PyTorchEstimators,
-        data: List[Dict[str, Tensor]],
-        state: FitState,
-        control: FitControl,
-        res_loss: float,
-        exception: Exception,
-        **kwargs
-    ) -> None:
-        if isinstance(exception, KeyboardInterrupt):
-            print(
-                "\nInterruption par la commande KeyboardInterrupt.",
-                flush=True
-            )
-            self.end_train(
-                model=model,
-                data=data,
-                state=state,
-                control=control,
-                res_loss=res_loss,
-                **kwargs
-            )
-
 
 @dataclass
 class LRSchedulerCallback(CallbackInterface, metaclass=SuperclassDocstring):
@@ -1113,7 +1092,7 @@ class LRSchedulerCallback(CallbackInterface, metaclass=SuperclassDocstring):
                             os.listdir(f"{self.path_backup}/")
                         )
                     ),
-                    key=lambda x: os.path.getmtime(x),
+                    key=lambda x: os.path.getmtime(f"{self.path_backup}/{x}"),
                     reverse=True
                 )[self.nb_backup:]
                 for file in files:
